package jp.ac.takushoku_u.cs;

/**
* DisagreementMatrixSizeException饹2ĤΥޥȥꥯФӤ黻Ԥݡ
* 2ĤΥޥȥꥯΥפʤ
* ⤷ϱ黻ԤʤƱΤǤ뤳Ȥ򼨤˥ޤ
* @version 1.2
* @author  ͵(Kasajima Hiroshi)
*/
/*
* ǽ 2004ǯ1209
*/

public class DisagreementMatrixSizeException extends DisagreementSizeException{

/**
* åʤ DisagreementMatrixSizeException ۤޤ
*/
	public DisagreementMatrixSizeException(){
		super();
	}
	
/**
* ꤷܺ٥å DisagreementMatrixSizeException ۤޤ
* @param s ܺ٥å
*/
	public DisagreementMatrixSizeException(String s){
		super(s);
	}
}